@@ -1,18 +1,11 @@
 from typing import Any, Dict, List, Optional, Sequence, Set
 
-from dagster import (
-    Field,
-    InputDefinition,
-    OpDefinition,
-    OpExecutionContext,
-    OutputDefinition,
-)
-from dagster.core.definitions.events import Output
+from dagster import Field, In, OpDefinition, OpExecutionContext, Out, Output
 
 
 class BaseComponent:
-    input_defs: List[InputDefinition] = []
-    output_defs: List[OutputDefinition] = []
+    input_defs: Dict[str, In] = {}
+    output_defs: Dict[str, Out] = {}
     config_schema: Dict[str, Field] = {}
     required_resource_keys: Set[str] = set()
     tags: Dict[str, str] = {}
@@ -58,8 +51,8 @@ class BaseComponent:
 
         Args:
             name (str): The name of the op.
-            input_defs (List[InputDefinition], optional): The list of Dagster input values. Defaults to [].
-            output_defs (List[OutputDefinition], optional): The list of Dagster output values. Defaults to [].
+            input_defs (List[In], optional): The list of Dagster input values. Defaults to [].
+            output_defs (List[Out], optional): The list of Dagster output values. Defaults to [].
 
         Returns:
             OpDefinition: The operator that is used by Dagster to execute this component.
@@ -67,8 +60,8 @@ class BaseComponent:
         return OpDefinition(
             name=name,
             description=description,
-            input_defs=cls.input_defs,
-            output_defs=cls.output_defs,
+            ins=cls.input_defs,
+            outs=cls.output_defs,
             required_resource_keys=cls.required_resource_keys,
             config_schema=cls.config_schema,
             compute_fn=cls._compute_hook,
