@@ -2,7 +2,7 @@ from typing import Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import InputDefinition, Nothing, OutputDefinition
+from dagster import In, Nothing, Out
 from qdk.base import BaseComponent
 from qdk.dagster_types import DataFrameType
 
@@ -12,12 +12,8 @@ class BaseExporter(BaseComponent):
     tags = {
         "kind": "export",
     }
-    input_defs = [
-        InputDefinition("df", DataFrameType),
-    ]
-    output_defs = [
-        OutputDefinition(Nothing, "after"),
-    ]
+    input_defs = {"df": In(DataFrameType)}
+    output_defs = {"after": Out(Nothing)}
 
     @classmethod
     def export(
