@@ -2,7 +2,7 @@ from typing import Dict, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Any, InputDefinition, OutputDefinition
+from dagster import Any, In, Out
 from qdk.base import BaseComponent
 
 
@@ -11,13 +11,8 @@ class BaseInference(BaseComponent):
     tags = {
         "kind": "inference",
     }
-    input_defs = [
-        InputDefinition("data", pd.DataFrame),
-        InputDefinition("model", Any),
-    ]
-    output_defs = [
-        OutputDefinition(pd.DataFrame, "predictions"),
-    ]
+    input_defs = {"data": In(pd.DataFrame), "model": In(Any)}
+    output_defs = {"predictions": Out(pd.DataFrame)}
 
     @classmethod
     def predict(
