@@ -1,6 +1,6 @@
 from typing import Union
 
-from dagster import InputDefinition, OutputDefinition
+from dagster import In, Out
 from dask.dataframe import DataFrame as DaskDataFrame
 from dask.dataframe import Series as DaskSeries
 from pandas import DataFrame, Series
@@ -11,14 +11,12 @@ from qdk.mlflow import MLFlowRun
 
 class MLFlowInference(BaseInference):
     compute_function = "predict"
-    input_defs = [
-        InputDefinition("X", DataFrameType),
-        InputDefinition("mlflow_run", MLFlowRunType),
-        InputDefinition("y_true", SeriesType, default_value=None),
-    ]
-    output_defs = [
-        OutputDefinition(DataFrameType, "X_hat"),
-    ]
+    input_defs = {
+        "X": In(DataFrameType),
+        "mlflow_run": In(MLFlowRunType),
+        "y_true": In(SeriesType, default_value=None),
+    }
+    output_defs = {"X_hat": Out(DataFrameType)}
 
     @classmethod
     def predict(
