@@ -1,16 +1,13 @@
 import pickle
 from typing import Any
 
-from dagster import Field, OutputDefinition, StringSource
+from dagster import Field, Out, StringSource
 from dagster_aws.s3 import s3_resource
 from qdk.loader.base import BaseLoader
 
 
 class S3PickleLoader(BaseLoader):
-    output_defs = [
-        OutputDefinition(Any, "result"),
-    ]
-
+    output_defs = {"result": Out(Any)}
     config_schema = {
         "bucket": Field(
             StringSource,
