@@ -1,7 +1,7 @@
 from abc import ABC, abstractstaticmethod
 from typing import Any, Dict, List, Optional
 
-from dagster import AssetMaterialization, EventMetadata, OutputContext
+from dagster import AssetMaterialization, MetadataValue, OutputContext
 from dask.dataframe import DataFrame as DaskDataFrame
 from pandas import DataFrame
 
@@ -29,8 +29,8 @@ class PandasDataFrameMetaData(MetaData):
             "columns": list_to_string(object.columns),
             "dask": 0,
             "length": len(object),
-            "head": EventMetadata.md(object.head().to_markdown()),
-            "tail": EventMetadata.md(object.tail().to_markdown()),
+            "head": MetadataValue.md(object.head().to_markdown()),
+            "tail": MetadataValue.md(object.tail().to_markdown()),
         }
 
 
@@ -55,10 +55,10 @@ class MLFlowRunMetaData(MetaData):
         return {
             "run_id": object.run_id,
             "model_flavors": list_to_string(object.model_flavors),
-            "run_url": EventMetadata.url(object.run_url),
-            "run_url_local": EventMetadata.url(object.run_url_local),
-            "input_schema": EventMetadata.md(object.input_schema.to_markdown()),
-            "output_schema": EventMetadata.md(object.output_schema.to_markdown()),
+            "run_url": MetadataValue.url(object.run_url),
+            "run_url_local": MetadataValue.url(object.run_url_local),
+            "input_schema": MetadataValue.md(object.input_schema.to_markdown()),
+            "output_schema": MetadataValue.md(object.output_schema.to_markdown()),
         }
 
 
