@@ -2,7 +2,7 @@ from typing import Any, Dict, Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import Field, OutputDefinition, Permissive
+from dagster import Field, Out, Permissive
 from qdk.dagster_types import MLFlowRunType
 from qdk.mlflow import MLFlowRun
 from qdk.training.base import BaseTrainer
@@ -12,9 +12,7 @@ from sklearn.base import BaseEstimator
 
 
 class MLFlowTrainingComponent(BaseTrainer):
-    output_defs = [
-        OutputDefinition(MLFlowRunType, "mlflow_run"),
-    ]
+    output_defs = {"mlflow_run": Out(MLFlowRunType)}
     config_schema = {
         "experiment_name": Field(
             str,
