@@ -2,7 +2,7 @@ from typing import Union
 
 import dask.dataframe as dd
 import pandas as pd
-from dagster import InputDefinition, OutputDefinition
+from dagster import In, Out
 from qdk.base import BaseComponent
 from qdk.dagster_types import DataFrameType
 
@@ -12,12 +12,8 @@ class BaseTransformer(BaseComponent):
     tags = {
         "kind": "transform",
     }
-    input_defs = [
-        InputDefinition("df", DataFrameType),
-    ]
-    output_defs = [
-        OutputDefinition(DataFrameType, "df"),
-    ]
+    input_defs = {"df": In(DataFrameType)}
+    output_defs = {"df": Out(DataFrameType)}
 
     @classmethod
     def transform(
